==> gimp-1.2.3-i386-1.tgz: install/doinst.sh <==
( cd usr/bin ; rm -rf escputil )
( cd usr/bin ; ln -sf escputil-1.2 escputil )
( cd usr/bin ; rm -rf gimp )
( cd usr/bin ; ln -sf gimp-1.2 gimp )
( cd usr/bin ; rm -rf gimp-config )
( cd usr/bin ; ln -sf gimptool-1.2 gimp-config )
( cd usr/bin ; rm -rf gimp-remote )
( cd usr/bin ; ln -sf gimp-remote-1.2 gimp-remote )
( cd usr/bin ; rm -rf gimptool )
( cd usr/bin ; ln -sf gimptool-1.2 gimptool )
( cd usr/lib ; rm -rf libgck-1.2.so.0 )
( cd usr/lib ; ln -sf libgck-1.2.so.0.0.3 libgck-1.2.so.0 )
( cd usr/lib ; rm -rf libgck.so )
( cd usr/lib ; ln -sf libgck-1.2.so.0.0.3 libgck.so )
( cd usr/lib ; rm -rf libgimp-1.2.so.0 )
( cd usr/lib ; ln -sf libgimp-1.2.so.0.0.3 libgimp-1.2.so.0 )
( cd usr/lib ; rm -rf libgimp.so )
( cd usr/lib ; ln -sf libgimp-1.2.so.0.0.3 libgimp.so )
( cd usr/lib ; rm -rf libgimpui-1.2.so.0 )
( cd usr/lib ; ln -sf libgimpui-1.2.so.0.0.3 libgimpui-1.2.so.0 )
( cd usr/lib ; rm -rf libgimpui.so )
( cd usr/lib ; ln -sf libgimpui-1.2.so.0.0.3 libgimpui.so )
( cd usr/man/man1 ; rm -rf escputil.1.gz )
( cd usr/man/man1 ; ln -sf escputil-1.2.1.gz escputil.1.gz )
( cd usr/man/man1 ; rm -rf gimp-remote.1.gz )
( cd usr/man/man1 ; ln -sf gimp-remote-1.2.1.gz gimp-remote.1.gz )
( cd usr/man/man1 ; rm -rf gimp.1.gz )
( cd usr/man/man1 ; ln -sf gimp-1.2.1.gz gimp.1.gz )
( cd usr/man/man1 ; rm -rf gimptool.1.gz )
( cd usr/man/man1 ; ln -sf gimptool-1.2.1.gz gimptool.1.gz )
( cd usr/man/man5 ; rm -rf gimprc.5.gz )
( cd usr/man/man5 ; ln -sf gimprc-1.2.5.gz gimprc.5.gz )
( cd usr/share/gimp/1.2/help/C/channels ; rm -rf dialogs )
( cd usr/share/gimp/1.2/help/C/channels ; ln -sf ../dialogs/channels dialogs )
( cd usr/share/gimp/1.2/help/C/file ; rm -rf dialogs )
( cd usr/share/gimp/1.2/help/C/file ; ln -sf ../dialogs dialogs )
( cd usr/share/gimp/1.2/help/C/file ; rm -rf filters )
( cd usr/share/gimp/1.2/help/C/file ; ln -sf ../filters filters )
( cd usr/share/gimp/1.2/help/C/file ; rm -rf open )
( cd usr/share/gimp/1.2/help/C/file ; ln -sf ../open open )
( cd usr/share/gimp/1.2/help/C/file ; rm -rf save )
( cd usr/share/gimp/1.2/help/C/file ; ln -sf ../save save )
( cd usr/share/gimp/1.2/help/C/image ; rm -rf dialogs )
( cd usr/share/gimp/1.2/help/C/image ; ln -sf ../dialogs dialogs )
( cd usr/share/gimp/1.2/help/C/image/edit ; rm -rf dialogs )
( cd usr/share/gimp/1.2/help/C/image/edit ; ln -sf ../../dialogs dialogs )
( cd usr/share/gimp/1.2/help/C/image ; rm -rf file )
( cd usr/share/gimp/1.2/help/C/image ; ln -sf ../file file )
( cd usr/share/gimp/1.2/help/C/image ; rm -rf filters )
( cd usr/share/gimp/1.2/help/C/image ; ln -sf ../filters filters )
( cd usr/share/gimp/1.2/help/C/image/image ; rm -rf dialogs )
( cd usr/share/gimp/1.2/help/C/image/image ; ln -sf ../../dialogs dialogs )
( cd usr/share/gimp/1.2/help/C/image/image/mode ; rm -rf dialogs )
( cd usr/share/gimp/1.2/help/C/image/image/mode ; ln -sf ../../../dialogs dialogs )
( cd usr/share/gimp/1.2/help/C/image/image/transforms ; rm -rf dialogs )
( cd usr/share/gimp/1.2/help/C/image/image/transforms ; ln -sf ../../../dialogs dialogs )
( cd usr/share/gimp/1.2/help/C/image ; rm -rf layers )
( cd usr/share/gimp/1.2/help/C/image ; ln -sf ../layers layers )
( cd usr/share/gimp/1.2/help/C/image/select ; rm -rf dialogs )
( cd usr/share/gimp/1.2/help/C/image/select ; ln -sf ../../dialogs dialogs )
( cd usr/share/gimp/1.2/help/C/image ; rm -rf toolbox )
( cd usr/share/gimp/1.2/help/C/image ; ln -sf ../toolbox toolbox )
( cd usr/share/gimp/1.2/help/C/image ; rm -rf tools )
( cd usr/share/gimp/1.2/help/C/image ; ln -sf ../tools tools )
( cd usr/share/gimp/1.2/help/C/image/view ; rm -rf dialogs )
( cd usr/share/gimp/1.2/help/C/image/view ; ln -sf ../../dialogs dialogs )
( cd usr/share/gimp/1.2/help/C/layers ; rm -rf dialogs )
( cd usr/share/gimp/1.2/help/C/layers ; ln -sf ../dialogs/layers dialogs )
( cd usr/share/gimp/1.2/help/C/open ; rm -rf dialogs )
( cd usr/share/gimp/1.2/help/C/open ; ln -sf ../dialogs dialogs )
( cd usr/share/gimp/1.2/help/C/open ; rm -rf filters )
( cd usr/share/gimp/1.2/help/C/open ; ln -sf ../filters filters )
( cd usr/share/gimp/1.2/help/C/paths ; rm -rf dialogs )
( cd usr/share/gimp/1.2/help/C/paths ; ln -sf ../dialogs/paths dialogs )
( cd usr/share/gimp/1.2/help/C/paths ; rm -rf filters )
( cd usr/share/gimp/1.2/help/C/paths ; ln -sf ../filters filters )
( cd usr/share/gimp/1.2/help/C/save ; rm -rf dialogs )
( cd usr/share/gimp/1.2/help/C/save ; ln -sf ../dialogs dialogs )
( cd usr/share/gimp/1.2/help/C/save ; rm -rf filters )
( cd usr/share/gimp/1.2/help/C/save ; ln -sf ../filters filters )
( cd usr/share/gimp/1.2/help/C/toolbox ; rm -rf dialogs )
( cd usr/share/gimp/1.2/help/C/toolbox ; ln -sf ../dialogs dialogs )
( cd usr/share/gimp/1.2/help/C/toolbox ; rm -rf file )
( cd usr/share/gimp/1.2/help/C/toolbox ; ln -sf ../file file )
( cd usr/share/gimp/1.2/help/C/toolbox ; rm -rf filters )
( cd usr/share/gimp/1.2/help/C/toolbox ; ln -sf ../filters filters )
( cd usr/share/gimp/1.2/help/C/toolbox/help ; rm -rf dialogs )
( cd usr/share/gimp/1.2/help/C/toolbox/help ; ln -sf ../../dialogs dialogs )
( cd usr/share/gimp/1.2/help/C/toolbox/help ; rm -rf filters )
( cd usr/share/gimp/1.2/help/C/toolbox/help ; ln -sf ../../filters filters )

==> gimp-1.2.5-i486-1.tgz: install/doinst.sh <==
( cd usr/bin ; rm -rf gimp-remote )
( cd usr/bin ; ln -sf gimp-remote-1.2 gimp-remote )
( cd usr/bin ; rm -rf gimp )
( cd usr/bin ; ln -sf gimp-1.2 gimp )
( cd usr/bin ; rm -rf gimp-config )
( cd usr/bin ; ln -sf gimptool-1.2 gimp-config )
( cd usr/bin ; rm -rf gimptool )
( cd usr/bin ; ln -sf gimptool-1.2 gimptool )
( cd usr/lib ; rm -rf libgck.so )
( cd usr/lib ; ln -sf libgck-1.2.so.0.0.5 libgck.so )
( cd usr/lib ; rm -rf libgimpui-1.2.so.0 )
( cd usr/lib ; ln -sf libgimpui-1.2.so.0.0.5 libgimpui-1.2.so.0 )
( cd usr/lib ; rm -rf libgimp.so )
( cd usr/lib ; ln -sf libgimp-1.2.so.0.0.5 libgimp.so )
( cd usr/lib ; rm -rf libgimpui.so )
( cd usr/lib ; ln -sf libgimpui-1.2.so.0.0.5 libgimpui.so )
( cd usr/lib ; rm -rf libgck-1.2.so.0 )
( cd usr/lib ; ln -sf libgck-1.2.so.0.0.5 libgck-1.2.so.0 )
( cd usr/lib ; rm -rf libgimp-1.2.so.0 )
( cd usr/lib ; ln -sf libgimp-1.2.so.0.0.5 libgimp-1.2.so.0 )
( cd usr/man/man1 ; rm -rf gimp-remote.1.gz )
( cd usr/man/man1 ; ln -sf gimp-remote-1.2.1.gz gimp-remote.1.gz )
( cd usr/man/man1 ; rm -rf gimptool-1.gz )
( cd usr/man/man1 ; ln -sf gimptool-1.2.1.gz gimptool-1.gz )
( cd usr/man/man1 ; rm -rf gimp-1.gz )
( cd usr/man/man1 ; ln -sf gimp-1.2.1.gz gimp-1.gz )
( cd usr/man/man5 ; rm -rf gimprc-1.gz )
( cd usr/man/man5 ; ln -sf gimprc-1.2.5.gz gimprc-1.gz )
( cd usr/share/gimp/1.2/help/C/file ; rm -rf open )
( cd usr/share/gimp/1.2/help/C/file ; ln -sf ../open open )
( cd usr/share/gimp/1.2/help/C/file ; rm -rf save )
( cd usr/share/gimp/1.2/help/C/file ; ln -sf ../save save )
( cd usr/share/gimp/1.2/help/C/file ; rm -rf dialogs )
( cd usr/share/gimp/1.2/help/C/file ; ln -sf ../dialogs dialogs )
( cd usr/share/gimp/1.2/help/C/file ; rm -rf filters )
( cd usr/share/gimp/1.2/help/C/file ; ln -sf ../filters filters )
( cd usr/share/gimp/1.2/help/C/open ; rm -rf dialogs )
( cd usr/share/gimp/1.2/help/C/open ; ln -sf ../dialogs dialogs )
( cd usr/share/gimp/1.2/help/C/open ; rm -rf filters )
( cd usr/share/gimp/1.2/help/C/open ; ln -sf ../filters filters )
( cd usr/share/gimp/1.2/help/C/save ; rm -rf dialogs )
( cd usr/share/gimp/1.2/help/C/save ; ln -sf ../dialogs dialogs )
( cd usr/share/gimp/1.2/help/C/save ; rm -rf filters )
( cd usr/share/gimp/1.2/help/C/save ; ln -sf ../filters filters )
( cd usr/share/gimp/1.2/help/C/image/edit ; rm -rf dialogs )
( cd usr/share/gimp/1.2/help/C/image/edit ; ln -sf ../../dialogs dialogs )
( cd usr/share/gimp/1.2/help/C/image ; rm -rf file )
( cd usr/share/gimp/1.2/help/C/image ; ln -sf ../file file )
( cd usr/share/gimp/1.2/help/C/image/view ; rm -rf dialogs )
( cd usr/share/gimp/1.2/help/C/image/view ; ln -sf ../../dialogs dialogs )
( cd usr/share/gimp/1.2/help/C/image ; rm -rf dialogs )
( cd usr/share/gimp/1.2/help/C/image ; ln -sf ../dialogs dialogs )
( cd usr/share/gimp/1.2/help/C/image/image/mode ; rm -rf dialogs )
( cd usr/share/gimp/1.2/help/C/image/image/mode ; ln -sf ../../../dialogs dialogs )
( cd usr/share/gimp/1.2/help/C/image/image/transforms ; rm -rf dialogs )
( cd usr/share/gimp/1.2/help/C/image/image/transforms ; ln -sf ../../../dialogs dialogs )
( cd usr/share/gimp/1.2/help/C/image/image ; rm -rf dialogs )
( cd usr/share/gimp/1.2/help/C/image/image ; ln -sf ../../dialogs dialogs )
( cd usr/share/gimp/1.2/help/C/image ; rm -rf tools )
( cd usr/share/gimp/1.2/help/C/image ; ln -sf ../tools tools )
( cd usr/share/gimp/1.2/help/C/image ; rm -rf filters )
( cd usr/share/gimp/1.2/help/C/image ; ln -sf ../filters filters )
( cd usr/share/gimp/1.2/help/C/image ; rm -rf toolbox )
( cd usr/share/gimp/1.2/help/C/image ; ln -sf ../toolbox toolbox )
( cd usr/share/gimp/1.2/help/C/image ; rm -rf layers )
( cd usr/share/gimp/1.2/help/C/image ; ln -sf ../layers layers )
( cd usr/share/gimp/1.2/help/C/image/select ; rm -rf dialogs )
( cd usr/share/gimp/1.2/help/C/image/select ; ln -sf ../../dialogs dialogs )
( cd usr/share/gimp/1.2/help/C/paths ; rm -rf dialogs )
( cd usr/share/gimp/1.2/help/C/paths ; ln -sf ../dialogs/paths dialogs )
( cd usr/share/gimp/1.2/help/C/paths ; rm -rf filters )
( cd usr/share/gimp/1.2/help/C/paths ; ln -sf ../filters filters )
( cd usr/share/gimp/1.2/help/C/channels ; rm -rf dialogs )
( cd usr/share/gimp/1.2/help/C/channels ; ln -sf ../dialogs/channels dialogs )
( cd usr/share/gimp/1.2/help/C/toolbox ; rm -rf file )
( cd usr/share/gimp/1.2/help/C/toolbox ; ln -sf ../file file )
( cd usr/share/gimp/1.2/help/C/toolbox/help ; rm -rf dialogs )
( cd usr/share/gimp/1.2/help/C/toolbox/help ; ln -sf ../../dialogs dialogs )
( cd usr/share/gimp/1.2/help/C/toolbox/help ; rm -rf filters )
( cd usr/share/gimp/1.2/help/C/toolbox/help ; ln -sf ../../filters filters )
( cd usr/share/gimp/1.2/help/C/toolbox ; rm -rf dialogs )
( cd usr/share/gimp/1.2/help/C/toolbox ; ln -sf ../dialogs dialogs )
( cd usr/share/gimp/1.2/help/C/toolbox ; rm -rf filters )
( cd usr/share/gimp/1.2/help/C/toolbox ; ln -sf ../filters filters )
( cd usr/share/gimp/1.2/help/C/layers ; rm -rf dialogs )
( cd usr/share/gimp/1.2/help/C/layers ; ln -sf ../dialogs/layers dialogs )
